@@ -1,4 +1,4 @@
-use std::net::SocketAddr;
+use std::net::{IpAddr, SocketAddr};
 
 use crate::util::string_to_key;
 
@@ -63,21 +63,20 @@ impl WireGuardServer {
 #[pyfunction]
 pub fn start_wireguard_server(
     py: Python<'_>,
-    host: String,
+    host: IpAddr,
     port: u16,
     private_key: String,
     peer_public_keys: Vec<String>,
     handle_tcp_stream: PyObject,
     handle_udp_stream: PyObject,
-) -> PyResult<Bound<PyAny>> {
+) -> PyResult<Bound<'_, PyAny>> {
     let private_key = string_to_key(private_key)?;
     let peer_public_keys = peer_public_keys
         .into_iter()
         .map(string_to_key)
         .collect::<PyResult<Vec<PublicKey>>>()?;
     let conf = WireGuardConf {
-        host,
-        port,
+        listen_addr: SocketAddr::from((host, port)),
         private_key,
         peer_public_keys,
     };
