@@ -1,14 +1,13 @@
 pub use network::MAX_PACKET_SIZE;
 
+pub mod certificates;
+pub mod dns;
 pub mod intercept_conf;
 pub mod ipc;
-#[cfg(target_os = "macos")]
-pub mod macos;
 pub mod messages;
 pub mod network;
 pub mod packet_sources;
 pub mod processes;
 pub mod shutdown;
-pub mod util;
 #[cfg(windows)]
 pub mod windows;
