@@ -1,23 +1,24 @@
-use std::net::{Ipv6Addr, SocketAddr};
+use std::net::SocketAddr;
 
-use anyhow::{anyhow, Result};
+use super::task::NetworkTask;
+use crate::messages::{
+    NetworkCommand, NetworkEvent, SmolPacket, TransportCommand, TransportEvent, TunnelInfo,
+};
+use crate::shutdown;
+use anyhow::{Result, anyhow};
+use core::net::Ipv4Addr;
+use core::net::Ipv6Addr;
 use internet_packet::InternetPacket;
 use smoltcp::{phy::ChecksumCapabilities, wire::*};
+use tokio::sync::watch;
 use tokio::{
     sync::{
-        broadcast::{self, Sender as BroadcastSender},
-        mpsc::{channel, unbounded_channel, Receiver, Sender, UnboundedSender},
+        mpsc::{Receiver, Sender, UnboundedSender, channel, unbounded_channel},
         oneshot,
     },
     task::JoinHandle,
 };
 
-use crate::messages::{
-    NetworkCommand, NetworkEvent, SmolPacket, TransportCommand, TransportEvent, TunnelInfo,
-};
-
-use super::task::NetworkTask;
-
 struct MockNetwork {
     wg_to_smol_tx: Sender<NetworkEvent>,
     smol_to_wg_rx: Receiver<NetworkCommand>,
@@ -25,7 +26,7 @@ struct MockNetwork {
     py_to_smol_tx: UnboundedSender<TransportCommand>,
     smol_to_py_rx: Receiver<TransportEvent>,
 
-    sd_trigger: BroadcastSender<()>,
+    sd_trigger: watch::Sender<()>,
     handle: JoinHandle<Result<()>>,
 }
 
@@ -37,7 +38,7 @@ impl MockNetwork {
         let (py_to_smol_tx, py_to_smol_rx) = unbounded_channel();
         let (smol_to_py_tx, smol_to_py_rx) = channel(64);
 
-        let (sd_trigger, sd_watcher) = broadcast::channel(1);
+        let (sd_trigger, sd_watcher) = shutdown::channel();
 
         let task = NetworkTask::new(
             smol_to_wg_tx,
@@ -45,7 +46,7 @@ impl MockNetwork {
             smol_to_py_tx,
             py_to_smol_rx,
             sd_watcher,
-        )?;
+        );
 
         let handle = tokio::spawn(task.run());
 
@@ -100,8 +101,8 @@ impl MockNetwork {
 
 #[allow(clippy::too_many_arguments)]
 fn build_ipv4_tcp_packet(
-    src_addr: Ipv4Address,
-    dst_addr: Ipv4Address,
+    src_addr: Ipv4Addr,
+    dst_addr: Ipv4Addr,
     src_port: u16,
     dst_port: u16,
     control: TcpControl,
@@ -120,6 +121,7 @@ fn build_ipv4_tcp_packet(
         max_seg_size: Some(1380),
         sack_permitted: true,
         sack_ranges: [None, None, None],
+        timestamp: None,
         payload,
     };
 
@@ -148,8 +150,8 @@ fn build_ipv4_tcp_packet(
 
 #[allow(clippy::too_many_arguments)]
 fn build_ipv6_tcp_packet(
-    src_addr: Ipv6Address,
-    dst_addr: Ipv6Address,
+    src_addr: Ipv6Addr,
+    dst_addr: Ipv6Addr,
     src_port: u16,
     dst_port: u16,
     control: TcpControl,
@@ -168,6 +170,7 @@ fn build_ipv6_tcp_packet(
         max_seg_size: Some(1380),
         sack_permitted: true,
         sack_ranges: [None, None, None],
+        timestamp: None,
         payload,
     };
 
@@ -195,8 +198,8 @@ fn build_ipv6_tcp_packet(
 }
 
 fn build_ipv4_udp_packet(
-    src_addr: Ipv4Address,
-    dst_addr: Ipv4Address,
+    src_addr: Ipv4Addr,
+    dst_addr: Ipv4Addr,
     src_port: u16,
     dst_port: u16,
     payload: &[u8],
@@ -229,8 +232,8 @@ fn build_ipv4_udp_packet(
 }
 
 fn build_ipv6_udp_packet(
-    src_addr: Ipv6Address,
-    dst_addr: Ipv6Address,
+    src_addr: Ipv6Addr,
+    dst_addr: Ipv6Addr,
     src_port: u16,
     dst_port: u16,
     payload: &[u8],
@@ -263,8 +266,8 @@ fn build_ipv6_udp_packet(
 }
 
 fn build_icmp4_echo_packet(
-    src_addr: Ipv4Address,
-    dst_addr: Ipv4Address,
+    src_addr: Ipv4Addr,
+    dst_addr: Ipv4Addr,
     ident: u16,
     seq_no: u16,
     data: &[u8],
@@ -295,8 +298,8 @@ fn build_icmp4_echo_packet(
 }
 
 fn build_icmp6_echo_packet(
-    src_addr: Ipv6Address,
-    dst_addr: Ipv6Address,
+    src_addr: Ipv6Addr,
+    dst_addr: Ipv6Addr,
     ident: u16,
     seq_no: u16,
     data: &[u8],
@@ -319,8 +322,8 @@ fn build_icmp6_echo_packet(
     let mut output_ipv6_packet = Ipv6Packet::new_unchecked(buf);
     ip_repr.emit(&mut output_ipv6_packet);
     icmp_repr.emit(
-        &IpAddress::from(src_addr),
-        &IpAddress::from(dst_addr),
+        &src_addr,
+        &dst_addr,
         &mut Icmpv6Packet::new_unchecked(output_ipv6_packet.payload_mut()),
         &ChecksumCapabilities::default(),
     );
@@ -392,8 +395,8 @@ async fn udp_read_write(
 #[tokio::test]
 async fn ipv4_udp() -> Result<()> {
     init_logger();
-    let src_addr = Ipv4Address([10, 0, 0, 1]);
-    let dst_addr = Ipv4Address([10, 0, 0, 42]);
+    let src_addr = "10.0.0.1".parse()?;
+    let dst_addr = "10.0.0.42".parse()?;
     let data = "hello world!".as_bytes();
 
     let udp_ip_packet = build_ipv4_udp_packet(src_addr, dst_addr, 1234, 31337, data);
@@ -410,19 +413,17 @@ async fn ipv4_udp() -> Result<()> {
 async fn ipv6_udp() -> Result<()> {
     init_logger();
 
-    let src: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:01".parse()?;
-    let dst: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:02".parse()?;
+    let src_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:01".parse()?;
+    let dst_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:02".parse()?;
 
-    let src_addr = Ipv6Address::from(src);
-    let dst_addr = Ipv6Address::from(dst);
     let data = "hello world!".as_bytes();
 
     let udp_ip_packet = build_ipv6_udp_packet(src_addr, dst_addr, 1234, 31337, data);
 
     udp_read_write(
         udp_ip_packet.into(),
-        SocketAddr::from((src, 1234)),
-        SocketAddr::from((dst, 31337)),
+        SocketAddr::from((src_addr, 1234)),
+        SocketAddr::from((dst_addr, 31337)),
     )
     .await
 }
@@ -433,8 +434,8 @@ async fn tcp_ipv4_connection() -> Result<()> {
     let mut mock = MockNetwork::init().await?;
     let mut seq = TcpSeqNumber(rand::random::<i32>());
 
-    let src_addr = Ipv4Address([10, 0, 0, 1]);
-    let dst_addr = Ipv4Address([10, 0, 0, 42]);
+    let src_addr = "10.0.0.1".parse()?;
+    let dst_addr = "10.0.0.42".parse()?;
     let data = "hello world!".as_bytes();
 
     // send TCP SYN
@@ -610,8 +611,8 @@ async fn tcp_ipv6_connection() -> Result<()> {
     let mut mock = MockNetwork::init().await?;
     let mut seq = TcpSeqNumber(rand::random::<i32>());
 
-    let src_addr = Ipv6Address(b"cafecafecafe0001".to_owned());
-    let dst_addr = Ipv6Address(b"cafecafecafe0002".to_owned());
+    let src_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:01".parse()?;
+    let dst_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:02".parse()?;
     let data = "hello world!".as_bytes();
 
     // send TCP SYN
@@ -786,8 +787,8 @@ async fn receive_icmp4_echo() -> Result<()> {
     init_logger();
     let mut mock = MockNetwork::init().await?;
 
-    let src_addr = Ipv4Address([10, 0, 0, 1]);
-    let dst_addr = Ipv4Address([10, 0, 0, 42]);
+    let src_addr = "10.0.0.1".parse()?;
+    let dst_addr = "10.0.0.42".parse()?;
     let data = "hello world!".as_bytes();
 
     let icmp_echo_ip_packet = build_icmp4_echo_packet(src_addr, dst_addr, 42, 31337, data);
@@ -804,7 +805,7 @@ async fn receive_icmp4_echo() -> Result<()> {
         let mut input_icmpv4_packet = match Icmpv4Packet::new_checked(response.payload_mut()) {
             Ok(p) => p,
             Err(e) => {
-                return Err(anyhow!("Invalid ICMPv4 packet emitted: {}", e.to_string()));
+                return Err(anyhow!("Invalid ICMPv4 packet emitted: {e}"));
             }
         };
 
@@ -824,8 +825,8 @@ async fn receive_icmp6_echo() -> Result<()> {
     init_logger();
     let mut mock = MockNetwork::init().await?;
 
-    let src_addr = Ipv6Address(b"cafecafecafe0001".to_owned());
-    let dst_addr = Ipv6Address(b"cafecafecafe0002".to_owned());
+    let src_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:01".parse()?;
+    let dst_addr: Ipv6Addr = "ca:fe:ca:fe:ca:fe:00:02".parse()?;
     let data = "hello world!".as_bytes();
 
     let icmp_echo_ip_packet = build_icmp6_echo_packet(src_addr, dst_addr, 42, 31337, data);
@@ -842,7 +843,7 @@ async fn receive_icmp6_echo() -> Result<()> {
         let mut input_icmpv6_packet = match Icmpv6Packet::new_checked(response.payload_mut()) {
             Ok(p) => p,
             Err(e) => {
-                return Err(anyhow!("Invalid ICMPv6 packet emitted: {}", e.to_string()));
+                return Err(anyhow!("Invalid ICMPv6 packet emitted: {e}"));
             }
         };
 
